diff --git a/r5dev/client/cdll_engine_int.cpp b/r5dev/client/cdll_engine_int.cpp
index d41076e5..13c4ad5b 100644
--- a/r5dev/client/cdll_engine_int.cpp
+++ b/r5dev/client/cdll_engine_int.cpp
@@ -38,7 +38,7 @@ void __fastcall HFrameStageNotify(CHLClient* rcx, ClientFrameStage_t frameStage)
 				ConCommandBase* disconnect = (ConCommandBase*)g_pCvar->FindCommand("disconnect");
 				disconnect->AddFlags(FCVAR_SERVER_CAN_EXECUTE); // Make sure server is not restricted to this.
 
-				if (net_userandomkey->m_pParent->m_iValue == 1)
+				if (net_userandomkey->GetBool())
 				{
 					HNET_GenerateKey();
 				}
diff --git a/r5dev/engine/host_state.cpp b/r5dev/engine/host_state.cpp
index 1a741f37..5f7f0cd0 100644
--- a/r5dev/engine/host_state.cpp
+++ b/r5dev/engine/host_state.cpp
@@ -14,7 +14,7 @@
 //-----------------------------------------------------------------------------
 void KeepAliveToPylon()
 {
-	if (g_pHostState->m_bActiveGame && sv_pylonvisibility->m_iValue == 1) // Check for active game.
+	if (g_pHostState->m_bActiveGame && sv_pylonvisibility->GetBool()) // Check for active game.
 	{
 		std::string m_szHostToken = std::string();
 		std::string m_szHostRequestMessage = std::string();
@@ -160,12 +160,12 @@ void HCHostState_FrameUpdate(void* rcx, void* rdx, float time)
 				}
 		});
 
-		if (net_userandomkey->m_pParent->m_iValue == 1)
+		if (net_userandomkey->GetBool())
 		{
 			HNET_GenerateKey();
 		}
 
-		g_pCvar->FindVar("net_usesocketsforloopback")->m_pParent->m_iValue = 1;
+		g_pCvar->FindVar("net_usesocketsforloopback")->SetValue(1);
 
 		bInitialized = true;
 	}
@@ -234,7 +234,7 @@ void HCHostState_FrameUpdate(void* rcx, void* rdx, float time)
 				g_pHostState->m_iCurrentState = HostStates_t::HS_RUN; // Set current state to run.
 
 				// If our next state isn't a shutdown or its a forced shutdown then set next state to run.
-				if (g_pHostState->m_iNextState != HostStates_t::HS_SHUTDOWN || !g_pCvar->FindVar("host_hasIrreversibleShutdown")->m_pParent->m_iValue)
+				if (g_pHostState->m_iNextState != HostStates_t::HS_SHUTDOWN || !g_pCvar->FindVar("host_hasIrreversibleShutdown")->GetBool())
 				{
 					g_pHostState->m_iNextState = HostStates_t::HS_RUN;
 				}
@@ -264,7 +264,7 @@ void HCHostState_FrameUpdate(void* rcx, void* rdx, float time)
 				g_pHostState->m_iCurrentState = HostStates_t::HS_RUN; // Set current state to run.
 
 				// If our next state isn't a shutdown or its a forced shutdown then set next state to run.
-				if (g_pHostState->m_iNextState != HostStates_t::HS_SHUTDOWN || !g_pCvar->FindVar("host_hasIrreversibleShutdown")->m_pParent->m_iValue)
+				if (g_pHostState->m_iNextState != HostStates_t::HS_SHUTDOWN || !g_pCvar->FindVar("host_hasIrreversibleShutdown")->GetBool())
 				{
 					g_pHostState->m_iNextState = HostStates_t::HS_RUN;
 				}
@@ -297,7 +297,7 @@ void HCHostState_FrameUpdate(void* rcx, void* rdx, float time)
 				g_pHostState->m_iCurrentState = HostStates_t::HS_RUN; // Set current state to run.
 
 				// If our next state isn't a shutdown or its a forced shutdown then set next state to run.
-				if (g_pHostState->m_iNextState != HostStates_t::HS_SHUTDOWN || !g_pCvar->FindVar("host_hasIrreversibleShutdown")->m_pParent->m_iValue)
+				if (g_pHostState->m_iNextState != HostStates_t::HS_SHUTDOWN || !g_pCvar->FindVar("host_hasIrreversibleShutdown")->GetBool())
 				{
 					g_pHostState->m_iNextState = HostStates_t::HS_RUN;
 				}
@@ -337,7 +337,7 @@ void HCHostState_FrameUpdate(void* rcx, void* rdx, float time)
 			}
 			}
 
-		} while ((oldState != HostStates_t::HS_RUN || g_pHostState->m_iNextState == HostStates_t::HS_LOAD_GAME && g_pCvar->FindVar("g_single_frame_shutdown_for_reload_cvar")->m_pParent->m_iValue)
+		} while ((oldState != HostStates_t::HS_RUN || g_pHostState->m_iNextState == HostStates_t::HS_LOAD_GAME && g_pCvar->FindVar("g_single_frame_shutdown_for_reload_cvar")->GetBool())
 			&& oldState != HostStates_t::HS_SHUTDOWN
 			&& oldState != HostStates_t::HS_RESTART);
 
diff --git a/r5dev/engine/net_chan.cpp b/r5dev/engine/net_chan.cpp
index c0937645..1c41b74b 100644
--- a/r5dev/engine/net_chan.cpp
+++ b/r5dev/engine/net_chan.cpp
@@ -78,7 +78,7 @@ void HNET_SetKey(std::string svNetKey)
 void HNET_GenerateKey()
 {
 	g_szNetKey.clear();
-	net_userandomkey->m_pParent->m_iValue = 1;
+	net_userandomkey->SetValue(1);
 
 	BCRYPT_ALG_HANDLE hAlgorithm;
 	if (BCryptOpenAlgorithmProvider(&hAlgorithm, L"RNG", 0, 0) < 0)
diff --git a/r5dev/networksystem/r5net.cpp b/r5dev/networksystem/r5net.cpp
index 4f814233..5a14a271 100644
--- a/r5dev/networksystem/r5net.cpp
+++ b/r5dev/networksystem/r5net.cpp
@@ -27,14 +27,14 @@ std::vector<ServerListing> R5Net::Client::GetServersList(std::string& svOutMessa
 
     std::string reqBodyStr = jsReqBody.dump();
 
-    if (r5net_show_debug->m_pParent->m_iValue > 0)
+    if (r5net_show_debug->GetBool())
     {
        DevMsg(eDLL_T::ENGINE, "Sending GetServerList post.\n");
     }
 
     httplib::Result htResults = m_HttpClient.Post("/servers", jsReqBody.dump().c_str(), jsReqBody.dump().length(), "application/json");
 
-    if (r5net_show_debug->m_pParent->m_iValue > 0)
+    if (r5net_show_debug->GetBool())
     {
         DevMsg(eDLL_T::ENGINE, "GetServerList replied with '%d'.\n", htResults->status);
     }
@@ -125,14 +125,14 @@ bool R5Net::Client::PostServerHost(std::string& svOutMessage, std::string& svOut
 
     std::string svRequestBody = jsRequestBody.dump();
 
-    if (r5net_show_debug->m_pParent->m_iValue > 0)
+    if (r5net_show_debug->GetBool())
     {
         DevMsg(eDLL_T::ENGINE, "Sending PostServerHost post '%s'.\n", svRequestBody.c_str());
     }
 
     httplib::Result htResults = m_HttpClient.Post("/servers/add", svRequestBody.c_str(), svRequestBody.length(), "application/json");
 
-    if (r5net_show_debug->m_pParent->m_iValue > 0)
+    if (r5net_show_debug->GetBool())
     {
         DevMsg(eDLL_T::ENGINE, "PostServerHost replied with '%d'.\n", htResults->status);
     }
@@ -213,14 +213,14 @@ bool R5Net::Client::GetServerByToken(ServerListing& slOutServer, std::string& sv
 
     jsRequestBody["token"] = svToken;
 
-    if (r5net_show_debug->m_pParent->m_iValue > 0)
+    if (r5net_show_debug->GetBool())
     {
         DevMsg(eDLL_T::ENGINE, "Sending GetServerByToken post.\n");
     }
 
     httplib::Result htResults = m_HttpClient.Post("/server/byToken", jsRequestBody.dump().c_str(), jsRequestBody.dump().length(), "application/json");
 
-    if (r5net_show_debug->m_pParent->m_iValue > 0)
+    if (r5net_show_debug->GetBool())
     {
         DevMsg(eDLL_T::ENGINE, "GetServerByToken replied with '%d'\n", htResults->status);
     }
diff --git a/r5dev/server/IVEngineServer.cpp b/r5dev/server/IVEngineServer.cpp
index 165c2584..ef250cae 100644
--- a/r5dev/server/IVEngineServer.cpp
+++ b/r5dev/server/IVEngineServer.cpp
@@ -18,7 +18,7 @@ bool HIVEngineServer_PersistenceAvailable(void* entidx, int clientidx)
 	CClient* pClient = g_pClient->GetClientInstance(clientidx);         // Get client instance.
 	*(char*)((std::uintptr_t)pClient + g_dwPersistenceVar) = (char)0x5; // Set the client instance to 'ready'.
 
-	if (!g_bIsPersistenceVarSet[clientidx] && sv_showconnecting->m_pParent->m_iValue > 0)
+	if (!g_bIsPersistenceVarSet[clientidx] && sv_showconnecting->GetBool())
 	{
 		void* clientNamePtr = (void**)(((std::uintptr_t)pClient->GetNetChan()) + 0x1A8D); // Get client name from netchan.
 		std::string clientName((char*)clientNamePtr, 32);                                // Get full name.
diff --git a/r5dev/server/server.cpp b/r5dev/server/server.cpp
index 7f8e9aec..027edcf8 100644
--- a/r5dev/server/server.cpp
+++ b/r5dev/server/server.cpp
@@ -44,7 +44,7 @@ void* HCServer_Authenticate(void* pServer, user_creds* pInpacket)
 		svIpAddress = ss.str();
 	}
 
-	if (sv_showconnecting->m_pParent->m_iValue > 0)
+	if (sv_showconnecting->GetBool())
 	{
 		DevMsg(eDLL_T::SERVER, "\n");
 		DevMsg(eDLL_T::SERVER, "______________________________________________________________\n");
@@ -61,7 +61,7 @@ void* HCServer_Authenticate(void* pServer, user_creds* pInpacket)
 		{
 			CServer_RejectConnection(pServer, *(unsigned int*)((std::uintptr_t)pServer + 0xC), pInpacket, "You have been banned from this Server."); // RejectConnection for the client.
 
-			if (sv_showconnecting->m_pParent->m_iValue > 0)
+			if (sv_showconnecting->GetBool())
 			{
 				DevMsg(eDLL_T::SERVER, "] NOTICE   : | THIS CLIENT IS BANNED!\n");
 				DevMsg(eDLL_T::SERVER, "--------------------------------------------------------------\n\n");
@@ -69,7 +69,7 @@ void* HCServer_Authenticate(void* pServer, user_creds* pInpacket)
 			return nullptr;
 		}
 	}
-	if (sv_showconnecting->m_pParent->m_iValue > 0)
+	if (sv_showconnecting->GetBool())
 	{
 		DevMsg(eDLL_T::SERVER, "\n");
 	}
diff --git a/r5dev/squirrel/sqvm.cpp b/r5dev/squirrel/sqvm.cpp
index 4eb69115..1e5f43c1 100644
--- a/r5dev/squirrel/sqvm.cpp
+++ b/r5dev/squirrel/sqvm.cpp
@@ -60,11 +60,11 @@ void* HSQVM_PrintFunc(void* sqvm, char* fmt, ...)
 
 	vmStr.append(buf);
 
-	if (sq_showvmoutput->m_pParent->m_iValue > 0)
+	if (sq_showvmoutput->GetInt() > 0)
 	{
 		sqlogger->debug(vmStr);
 	}
-	if (sq_showvmoutput->m_pParent->m_iValue > 1)
+	if (sq_showvmoutput->GetInt() > 1)
 	{
 		iconsole->debug(vmStr);
 		wconsole->debug(vmStr);
@@ -75,7 +75,7 @@ void* HSQVM_PrintFunc(void* sqvm, char* fmt, ...)
 #endif // !DEDICATED
 	}
 #ifndef DEDICATED
-	if (sq_showvmoutput->m_pParent->m_iValue > 2)
+	if (sq_showvmoutput->GetInt() > 2)
 	{
 		std::string s = g_spd_sqvm_p_oss.str();
 		g_pLogSystem.AddLog((LogType_t)vmIdx, s);
@@ -130,11 +130,11 @@ void* HSQVM_WarningFunc(void* sqvm, int a2, int a3, int* nStringSize, void** ppS
 	std::string s = g_spd_sqvm_w_oss.str();
 	const char* c = s.c_str();
 
-	if (sq_showvmwarning->m_pParent->m_iValue > 0)
+	if (sq_showvmwarning->GetInt() > 0)
 	{
 		sqlogger->debug(vmStr); // Emit to file.
 	}
-	if (sq_showvmwarning->m_pParent->m_iValue > 1)
+	if (sq_showvmwarning->GetInt() > 1)
 	{
 		iconsole->debug(vmStr); // Emit to in-game console.
 		wconsole->debug(vmStr); // Emit to windows console.
@@ -145,7 +145,7 @@ void* HSQVM_WarningFunc(void* sqvm, int a2, int a3, int* nStringSize, void** ppS
 #endif // !DEDICATED
 	}
 #ifndef DEDICATED
-	if (sq_showvmwarning->m_pParent->m_iValue > 2)
+	if (sq_showvmwarning->GetInt() > 2)
 	{
 		g_pLogSystem.AddLog((LogType_t)vmIdx, s);
 		const char* c = s.c_str();
@@ -186,7 +186,7 @@ void* HSQVM_LoadRson(const char* szRsonName)
 	// Returns the new path if the rson exists on the disk
 	if (FileExists(szFilePath) && SQVM_LoadRson(szRsonName))
 	{
-		if (sq_showrsonloading->m_pParent->m_iValue > 0)
+		if (sq_showrsonloading->GetBool())
 		{
 			DevMsg(eDLL_T::ENGINE, "\n");
 			DevMsg(eDLL_T::ENGINE, "______________________________________________________________\n");
@@ -199,7 +199,7 @@ void* HSQVM_LoadRson(const char* szRsonName)
 	}
 	else
 	{
-		if (sq_showrsonloading->m_pParent->m_iValue > 0)
+		if (sq_showrsonloading->GetBool())
 		{
 			DevMsg(eDLL_T::ENGINE, "\n");
 			DevMsg(eDLL_T::ENGINE, "______________________________________________________________\n");
@@ -229,7 +229,7 @@ bool HSQVM_LoadScript(void* sqvm, const char* szScriptPath, const char* szScript
 		}
 	}
 
-	if (sq_showscriptloading->m_pParent->m_iValue > 0)
+	if (sq_showscriptloading->GetBool())
 	{
 		DevMsg(eDLL_T::ENGINE, "Loading SQVM Script '%s'\n", filepath);
 	}
@@ -240,7 +240,7 @@ bool HSQVM_LoadScript(void* sqvm, const char* szScriptPath, const char* szScript
 		return true;
 	}
 
-	if (sq_showscriptloading->m_pParent->m_iValue > 0)
+	if (sq_showscriptloading->GetBool())
 	{
 		DevMsg(eDLL_T::ENGINE, "FAILED. Try SP / VPK for '%s'\n", filepath);
 	}
diff --git a/r5dev/tier0/ConCommand.cpp b/r5dev/tier0/ConCommand.cpp
index e072a129..72ba0552 100644
--- a/r5dev/tier0/ConCommand.cpp
+++ b/r5dev/tier0/ConCommand.cpp
@@ -105,13 +105,13 @@ bool ConCommandBase::HasFlags(int nFlags)
 //-----------------------------------------------------------------------------
 bool ConCommandBase::IsFlagSet(ConCommandBase* pCommandBase, int nFlags)
 {
-	if (cm_debug_cmdquery->m_pParent->m_iValue > 0)
+	if (cm_debug_cmdquery->GetBool())
 	{
 		printf("--------------------------------------------------\n");
 		printf(" Flaged: %08X\n", pCommandBase->m_nFlags);
 	}
 	// Mask off FCVAR_CHEATS and FCVAR_DEVELOPMENTONLY.
-	if (cm_return_false_cmdquery_cheats->m_pParent->m_iValue > 0)
+	if (cm_return_false_cmdquery_cheats->GetBool())
 	{
 		pCommandBase->RemoveFlags(FCVAR_DEVELOPMENTONLY | FCVAR_CHEAT);
 	}
@@ -119,18 +119,18 @@ bool ConCommandBase::IsFlagSet(ConCommandBase* pCommandBase, int nFlags)
 	{
 		pCommandBase->RemoveFlags(FCVAR_DEVELOPMENTONLY);
 	}
-	if (cm_debug_cmdquery->m_pParent->m_iValue > 0)
+	if (cm_debug_cmdquery->GetBool())
 	{
 		printf(" Masked: %08X\n", pCommandBase->m_nFlags);
 		printf(" Verify: %08X\n", nFlags);
 		printf("--------------------------------------------------\n");
 	}
-	if (nFlags & FCVAR_RELEASE && cm_return_false_cmdquery_all->m_pParent->m_iValue <= 0)
+	if (nFlags & FCVAR_RELEASE && cm_return_false_cmdquery_all->GetBool())
 	{
 		// Default retail behaviour.
 		return ConCommandBase_IsFlagSet(pCommandBase, nFlags);
 	}
-	if (cm_return_false_cmdquery_all->m_pParent->m_iValue > 0)
+	if (cm_return_false_cmdquery_all->GetBool())
 	{
 		// Returning false on all queries may cause problems.
 		return false;
diff --git a/r5dev/tier0/completion.cpp b/r5dev/tier0/completion.cpp
index 2c0ef44d..c2b23495 100644
--- a/r5dev/tier0/completion.cpp
+++ b/r5dev/tier0/completion.cpp
@@ -519,7 +519,7 @@ void _NET_TraceNetChan_f_CompletionFunc(CCommand* cmd)
 	static bool bTraceNetChannel = false;
 	if (!bTraceNetChannel)
 	{
-		g_pCvar->FindVar("net_usesocketsforloopback")->m_pParent->m_iValue = 1;
+		g_pCvar->FindVar("net_usesocketsforloopback")->SetValue(1);
 		DevMsg(eDLL_T::ENGINE, "\n");
 		DevMsg(eDLL_T::ENGINE, "+--------------------------------------------------------+\n");
 		DevMsg(eDLL_T::ENGINE, "|>>>>>>>>>>>>>| NETCHANNEL TRACE ACTIVATED |<<<<<<<<<<<<<|\n");
diff --git a/r5dev/vgui/CEngineVGui.cpp b/r5dev/vgui/CEngineVGui.cpp
index 407d7ed8..8124f9aa 100644
--- a/r5dev/vgui/CEngineVGui.cpp
+++ b/r5dev/vgui/CEngineVGui.cpp
@@ -78,13 +78,13 @@ void  CLogSystem::DrawLog()
 	{
 		if (m_vLogs[i].Ticks >= 0)
 		{
-			if (i < cl_consoleoverlay_lines->m_pParent->m_iValue)
+			if (i < cl_consoleoverlay_lines->GetInt())
 			{
 				float fadepct = fminf(static_cast<float>(m_vLogs[i].Ticks) / 255.f, 4.0); // TODO [ AMOS ]: register a ConVar for this!
 				float ptc = static_cast<int>(ceilf(fadepct * 100.f));                     // TODO [ AMOS ]: register a ConVar for this!
 				int alpha = static_cast<int>(ptc);
-				int y = (cl_consoleoverlay_offset_y->m_pParent->m_iValue + (fontHeight * i));
-				int x = cl_consoleoverlay_offset_x->m_pParent->m_iValue;
+				int y = (cl_consoleoverlay_offset_y->GetInt() + (fontHeight * i));
+				int x = cl_consoleoverlay_offset_x->GetInt();
 
 				Color c = GetLogColorForType(m_vLogs[i].Type);
 				CMatSystemSurface_DrawColoredText(g_pMatSystemSurface, 0x13, fontHeight, x, y, c._color[0], c._color[1], c._color[2], alpha, m_vLogs[i].Message.c_str());
diff --git a/r5dev/vpc/basefilesystem.cpp b/r5dev/vpc/basefilesystem.cpp
index fc127b30..3df3575e 100644
--- a/r5dev/vpc/basefilesystem.cpp
+++ b/r5dev/vpc/basefilesystem.cpp
@@ -9,7 +9,7 @@
 //---------------------------------------------------------------------------------
 void HCBaseFileSystem_Warning(void* thisptr, FileWarningLevel_t level, const char* fmt, ...)
 {
-	if (fs_warning_level_native->m_pParent->m_iValue < (int)level)
+	if (fs_warning_level_native->GetInt() < (int)level)
 	{
 		return;
 	}
diff --git a/r5dev/windows/id3dx.cpp b/r5dev/windows/id3dx.cpp
index cf0e7ee3..4bce7642 100644
--- a/r5dev/windows/id3dx.cpp
+++ b/r5dev/windows/id3dx.cpp
@@ -211,7 +211,7 @@ void GetPresent()
 		&nFeatureLevelsSupported,
 		&pContext)))
 	{
-		if (mat_showdxoutput->m_pParent->m_iValue > 0)
+		if (mat_showdxoutput->GetBool())
 		{
 			DevMsg(eDLL_T::MS, "+--------------------------------------------------------+\n");
 			DevMsg(eDLL_T::MS, "| >>>>>>>>>| VIRTUAL METHOD TABLE HOOK FAILED |<<<<<<<<< |\n");
@@ -346,7 +346,7 @@ void DestroyRenderTarget()
 		g_pRenderTargetView = nullptr;
 		g_pDeviceContext->OMSetRenderTargets(0, 0, 0);
 
-		if (mat_showdxoutput->m_pParent->m_iValue > 0)
+		if (mat_showdxoutput->GetBool())
 		{
 			DevMsg(eDLL_T::MS, "+--------------------------------------------------------+\n");
 			DevMsg(eDLL_T::MS, "| >>>>>>>>>>>>>>| RENDER TARGET DESTROYED |<<<<<<<<<<<<< |\n");
@@ -389,7 +389,7 @@ HRESULT __stdcall Present(IDXGISwapChain* pSwapChain, UINT nSyncInterval, UINT n
 	{
 		if (FAILED(GetDeviceAndCtxFromSwapchain(pSwapChain, &g_pDevice, &g_pDeviceContext)))
 		{
-			if (mat_showdxoutput->m_pParent->m_iValue > 0)
+			if (mat_showdxoutput->GetBool())
 			{
 				DevMsg(eDLL_T::MS, "+--------------------------------------------------------+\n");
 				DevMsg(eDLL_T::MS, "| >>>>>>>>>>| GET DVS AND CTX FROM SCP FAILED |<<<<<<<<< |\n");
diff --git a/r5dev/vpklib/packedstore.cpp b/r5dev/vpklib/packedstore.cpp
index 9ec260dd..8e070f68 100644
--- a/r5dev/vpklib/packedstore.cpp
+++ b/r5dev/vpklib/packedstore.cpp
@@ -66,11 +66,11 @@ vpk_dir_h CPackedStore::GetPackDirFile(std::string svPackDirFile)
 					{
 						std::string svPackDirPrefix = DIR_LOCALE_PREFIX[i] + DIR_LOCALE_PREFIX[i];
 						StringReplace(svPackDirFile, DIR_LOCALE_PREFIX[i].c_str(), svPackDirPrefix.c_str());
-						goto escape;
+						break;
 					}
 				}
 			}
-		}escape:;
+		}
 	}
 
 	vpk_dir_h vpk_dir(svPackDirFile);
@@ -124,9 +124,9 @@ std::string CPackedStore::StripLocalePrefix(std::string svPackDirFile)
 		if (strstr(svFileName.c_str(), DIR_LOCALE_PREFIX[i].c_str()))
 		{
 			StringReplace(svFileName, DIR_LOCALE_PREFIX[i].c_str(), "");
-			goto escape;
+			break;
 		}
-	}escape:;
+	}
 	return svFileName;
 }
 
@@ -197,8 +197,8 @@ void CPackedStore::UnpackAll(vpk_dir_h vpk_dir, std::string svPathOut)
 		{
 			if (block.m_iArchiveIndex != i)
 			{
-				// Continue if block archive index is not part of the extracting archive chunk index.
-				goto cont;
+				// Break if block archive index is not part of the extracting archive chunk index.
+				break;
 			}
 			else
 			{
@@ -223,7 +223,7 @@ void CPackedStore::UnpackAll(vpk_dir_h vpk_dir, std::string svPathOut)
 						lzham_uint8* pLzOutputBuf = new lzham_uint8[entry.m_nUncompressedSize];
 						m_lzDecompStatus = lzham_decompress_memory(&m_lzDecompParams, pLzOutputBuf, (size_t*)&entry.m_nUncompressedSize, (lzham_uint8*)pCompressedData, entry.m_nCompressedSize, &m_nAdler32_Internal, &m_nCrc32_Internal);
 
-						if (fs_packedstore_entryblock_stats->m_pParent->m_iValue > 0)
+						if (fs_packedstore_entryblock_stats->GetBool())
 						{
 							DevMsg(eDLL_T::FS, "--------------------------------------------------------------\n");
 							DevMsg(eDLL_T::FS, "] Block path            : '%s'\n", block.m_svBlockPath.c_str());